hyperiax.mcmc package
=====================

Submodules
----------

hyperiax.mcmc.fixedparameter module
-----------------------------------

.. automodule:: hyperiax.mcmc.fixedparameter
   :members:
   :undoc-members:
   :show-inheritance:

hyperiax.mcmc.metropolis\_hastings module
-----------------------------------------

.. automodule:: hyperiax.mcmc.metropolis_hastings
   :members:
   :undoc-members:
   :show-inheritance:

hyperiax.mcmc.parameter module
------------------------------

.. automodule:: hyperiax.mcmc.parameter
   :members:
   :undoc-members:
   :show-inheritance:

hyperiax.mcmc.parameterstore module
-----------------------------------

.. automodule:: hyperiax.mcmc.parameterstore
   :members:
   :undoc-members:
   :show-inheritance:

hyperiax.mcmc.plotting module
-----------------------------

.. automodule:: hyperiax.mcmc.plotting
   :members:
   :undoc-members:
   :show-inheritance:

hyperiax.mcmc.varianceParameter module
--------------------------------------

.. automodule:: hyperiax.mcmc.varianceParameter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hyperiax.mcmc
   :members:
   :undoc-members:
   :show-inheritance:
